@@ -1,10 +1,24 @@
+# frozen_string_literal: true
 #
-# Copyright (c) 2004-2010 David R. Halliday
-# All rights reserved.
+# Copyright (c) 2004-2014 David R. Halliday
 #
-# This SNMP library is free software.  Redistribution is permitted under the
-# same terms and conditions as the standard Ruby distribution.  See the
-# COPYING file in the Ruby distribution for details.
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+# THE SOFTWARE.
 #
 
 require 'snmp/pdu'
@@ -131,6 +145,7 @@ module SNMP
       option :mib_dir, :MibDir, MIB::DEFAULT_MIB_PATH
       option :mib_modules, :MibModules, default_modules
       option :use_IPv6, :use_IPv6, lambda { |c| ipv6_address?(c) }
+      option :ignore_oid_order, :IgnoreOidOrder, false
 
       def create_transport
         transport.respond_to?(:new) ? transport.new(socket_address_family) : transport
@@ -170,6 +185,7 @@ module SNMP
     #   :mib_dir            MIB::DEFAULT_MIB_PATH
     #   :mib_modules        SNMPv2-SMI, SNMPv2-MIB, IF-MIB, IP-MIB, TCP-MIB, UDP-MIB
     #   :use_IPv6           false, unless :host is formatted like an IPv6 address
+    #   :ignore_oid_order   false
     #
     # Use {:version => :SNMPv1} for SNMP v1.  SNMP v3 is not supported.
     #
@@ -189,7 +205,9 @@ module SNMP
       @transport = config.create_transport
       @max_bytes = config.max_recv_bytes
       @mib = MIB.new
-      load_modules(config.mib_modules, config.mib_dir)
+      @mib_dir = config.mib_dir
+      load_modules(config.mib_modules, @mib_dir)
+      @ignore_oid_order = config.ignore_oid_order
       @config = config.applied_config
     end
 
@@ -216,10 +234,6 @@ module SNMP
       @transport.close
     end
 
-    def load_module(name)
-      @mib.load_module(name)
-    end
-
     ##
     # Sends a get request for the supplied list of ObjectId or VarBind
     # objects.
@@ -427,7 +441,7 @@ module SNMP
         index_vb = vb_list[index_column]
         break if EndOfMibView == index_vb.value
         stop_oid = index_vb.name
-        if stop_oid <= last_oid
+        if !@ignore_oid_order && stop_oid <= last_oid
           warn "OIDs are not increasing, #{last_oid} followed by #{stop_oid}"
           break
         end
@@ -473,8 +487,12 @@ module SNMP
       @@request_id.force_next(request_id)
     end
 
-    def load_modules(module_list, mib_dir)
-      module_list.each { |m| @mib.load_module(m, mib_dir) }
+    def load_module(name, mib_dir = @mib_dir)
+      @mib.load_module(name, mib_dir)
+    end
+
+    def load_modules(module_list, mib_dir = @mib_dir)
+      module_list.each { |m| load_module(m, mib_dir) }
     end
 
     private
@@ -606,7 +624,8 @@ module SNMP
       @community = config.community
       @max_bytes = config.max_recv_bytes
       @mib = MIB.new
-      load_modules(config.mib_modules, config.mib_dir)
+      @mib_dir = config.mib_dir
+      load_modules(config.mib_modules, @mib_dir)
       @config = config.applied_config
 
       @handler_init = block
@@ -680,12 +699,16 @@ module SNMP
     alias kill exit
     alias terminate exit
 
-    private
-
-    def load_modules(module_list, mib_dir)
-      module_list.each { |m| @mib.load_module(m, mib_dir) }
+    def load_module(name, mib_dir = @mib_dir)
+      @mib.load_module(name, mib_dir)
     end
 
+    def load_modules(module_list, mib_dir = @mib_dir)
+      module_list.each { |m| load_module(m, mib_dir) }
+    end
+
+    private
+
     def process_traps(trap_listener)
       @handler_init.call(trap_listener) if @handler_init
       loop do
